@@ -1,6 +1,7 @@
 """ Plotting routines. """
 from __future__ import division
 
+from math import log10
 import numpy as np
 import matplotlib.pyplot as pl
 from matplotlib.collections import PolyCollection, LineCollection
@@ -347,7 +348,9 @@ def histo(a, fmt='b', bins=10, ax=None, lw=2, log=False, **kwargs):
         pl.figure()
         ax = pl.gca()
 
-    vals,bins = np.histogram(np.asarray(a).ravel(), bins=bins)
+    a = np.asarray(a).ravel()
+    a = a[~np.isnan(a)]
+    vals,bins = np.histogram(a, bins=bins)
     if log:
         vals = np.where(vals > 0, np.log10(vals), vals)
     b = np.repeat(bins, 2)
@@ -562,3 +565,73 @@ def draw_arrows(x, y, ax=None, capsize=2,  ms=6, direction='up',
                    edgecolors=c, **kwargs)
     return c
 
+def calc_log_minor_ticks(majticks):
+    """ Get minor tick positions for a log scale.
+
+    Parameters
+    ----------
+    majticks : array_like
+        log10 of the major tick positions.
+        
+    Returns
+    -------
+    minticks : ndarray
+        log10 of the minor tick positions.        
+    """
+    tickpos = np.log10(np.arange(2, 10))
+    minticks = []
+    for t in np.atleast_1d(majticks):
+        minticks.extend(t + tickpos)
+
+    return minticks
+
+def plot_ticks_wa(ax, wa, fl, height, ticks, keeponly=None, labels=True):
+    """ plot a ticks on a wavelength scale.
+
+    This plots ticks (such as those returned by `find_tau()`) on a
+    spectrum.
+
+    Parameters
+    ----------
+    ax : matplotlib axes
+      The axes on which to plot the ticks.
+    wa, fl : array_like
+      wavelength and flux of spectrum. `wa` must be sorted.
+    height : float
+      tick height in flux units.
+    ticks : record array
+      A record array of the sort returned by `find_tau`. The fields
+      wa, wa0, and name are required.
+    keeponly : str
+      If this is not None (the default), then only plot ticks that
+      contain this string in their name.
+    labels : bool (True)
+      Whether to plot labels next to the tickmarks.
+
+    Returns
+    -------
+    Ticks, Tlabels : Matplotlib collection of tickmarks and tick labels.
+      The artists corresponding to the ticks and their labels.
+    """
+    ind = wa.searchsorted(ticks.wa)
+    c0 = (ind == 0) | (ind == len(wa))
+    ticks = ticks[~c0]
+    ymin = fl[ind[~c0]]*1.1
+    Tlabels = []
+    c1 = np.ones(len(ticks), bool)
+    for i,t in enumerate(ticks):
+        if keeponly is not None:
+            if keeponly not in t.name:
+                c1[i] = False
+                continue
+        if not labels:
+            continue
+        label = '%s %.0f' % (t.name, t.wa0)
+        label = label.replace('NeVII', 'NeVIII')
+        Tlabels.append(ax.text(t.wa, ymin[i] + 1.1*height, label, rotation=60,
+                               fontsize=8, va='bottom', alpha=0.7))
+
+    Ticks = ax.vlines(ticks.wa[c1], ymin[c1], ymin[c1] + height, color='c',
+                      lw=1) 
+
+    return Ticks, Tlabels
