@@ -25,10 +25,11 @@ handled are:
 
 The package can be downloaded `here <https://github.com/nhmc/Barak>`_.
 
-It requires `NumPy <http://numpy.scipy.org/>`_, `Matplotlib
-<http://matplotlib.sourceforge.net/>`_, `SciPy
-<http://www.scipy.org/>`_, `ATpy <http://atpy.github.com/>`_ and
-`Astropy <http://www.astropy.org>`_.
+It requires `NumPy <http://numpy.scipy.org/>`_, `PyFits
+<http://www.stsci.edu/institute/software_hardware/pyfits/Download>`_
+and `ATpy <http://atpy.github.com/>`_ to install. `Matplotlib
+<http://matplotlib.sourceforge.net/>`_ and `SciPy
+<http://www.scipy.org/>`_ are also required for full functionality.
 
 To install, either download the tarball from the pypi website and then
 do::
@@ -42,8 +43,8 @@ using `pip`::
 
   pip install barak
 
-but you need to have `pip`
-(http://www.pip-installer.org/en/latest/index.html) installed.
+but you need to have `pip
+<http://www.pip-installer.org/en/latest/index.html>`_ installed.
 
 To run the tests you need `py.test <http://pytest.org/latest/>`_
 installed.  Then run::
@@ -124,11 +125,18 @@ def parse_module(modname, prefix='barak.'):
     s = section_head % (almostfullmodname, underline, moddoc, fullmodname)
     functions = sorted(list_functions(mod))
     classes = sorted(list_classes(mod))
+    print '  functions', functions
+    print '  classes', classes
     c = []
     for cla in classes:
+        print '  class', cla
+        try:
+            c0 = getattr(mod, cla)
+        except AttributeError:
+            continue
         c.append(cla)
-        temp = [cla + '.' + n for n in sorted(
-            set(list_methods(getattr(mod, cla))))]
+        methods = list_methods(c0)
+        temp = [cla + '.' + n for n in sorted(set(methods))]
         c.extend(temp)
 
     for obj in c + functions:
@@ -142,6 +150,7 @@ def process_scripts(pkgdir, filenames):
     descriptions = []
     nwidth = dwidth = 0
     for n in filenames:
+        print n
         fh = open(pkgdir + '/' + n)
         s = fh.read()
         fh.close()
@@ -203,6 +212,7 @@ if 1:
             modname = n.replace('./', '')[:-3]
             s += parse_module(modname, prefix=prefix)
 
+    print 'scripts'
     filenames = sorted(glob('../scripts/*'))
     s += process_scripts('../scripts/', filenames)
     
